@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12977 2021-06-16 07:01:50Z Becca $
+# $Id: __init__.py 12978 2021-06-16 09:15:13Z Becca $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Becca $ (last)
-# $Date: 2021-06-16 15:01:50 +0800 (Wed, 16 Jun 2021) $
-# $Revision: 12977 $
+# $Date: 2021-06-16 17:15:13 +0800 (Wed, 16 Jun 2021) $
+# $Revision: 12978 $
 
 from __future__ import print_function
 
@@ -982,36 +982,6 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                 raise KeyError(
                     "You should set DEVELOPMENT, STAGE, "
                     "PRODUCTION in IUNO_SITE_DOMAIN_NAMES")
-    #=========================================================================
-
-    #=========================================================================
-    # debug tool bar
-    try:
-        import debug_toolbar
-    except ImportError:
-        warnings.warn(
-            colored(
-                "Can't import debug_toolbar."
-                " Please install django-debug-toolbar==3.2.1.",
-                'yellow', attrs=['bold']
-            )
-        )
-    else:
-        if settingsDict.get('DEBUG_TOOLBAR_ENABLE', None):
-            extendInstalledApps(settingsDict, ('debug_toolbar',))
-            extendMiddlewareClasses(
-                settingsDict,
-                ("debug_toolbar.middleware.DebugToolbarMiddleware",)
-            )
-
-            toolbarSettings = {
-                'INTERNAL_IPS': ['127.0.0.1'],
-            }
-            update(settingsDict, toolbarSettings)
-
-            populateEnvToSettings((
-                'INTERNAL_IPS',
-            ), settingsDict)
 
 
 # detect Server mode
@@ -1051,16 +1021,6 @@ def checkImportPackageForAttachURLs(packageName):
     except ImportError:
         return False
 
-def attachDebugURLs(settings, urlpatterns):
-    """
-    Attach debug related urlpatterns.
-    It must be called in urls.py by passing urlpatterns.
-
-    @param settings Django project's settings module.
-    @param urlpatterns urlpatterns in urls.py.
-    """
-    from django.conf.urls import url, include
-
 def attachURLs(settings, urlpatterns, excludeApps=()):
     """
     Attach patched (for example, debug and admin...etc.) urlpatterns.
@@ -1078,16 +1038,6 @@ def attachURLs(settings, urlpatterns, excludeApps=()):
         url(r'^django-des/', include(des_urls)),
     )
 
-    try:
-        import debug_toolbar
-    except:
-        pass
-    else:
-        if settings.DEBUG:
-            urlpatterns += patterns('',
-                path(r'^__debug__/', include(debug_toolbar.urls)),
-            )
-
     #==========================================================================
     # Iuno.member.
     if not "Iuno.member" in excludeApps:
@@ -1164,5 +1114,18 @@ def attachURLs(settings, urlpatterns, excludeApps=()):
                     'document_root': settings.MEDIA_ROOT,
                 })
             )
+            
+    #==========================================================================
+    # DEBUG toolbar
+    if settings.DEBUG_TOOLBAR_ENABLE == True:
+        try:
+            import debug_toolbar
+        except:
+            pass
+        else:
+            if settings.DEBUG:
+                urlpatterns += patterns('',
+                    path(r'^__debug__/', include(debug_toolbar.urls)),
+                )
 
 
