@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backends.py 12906 2021-05-20 05:20:59Z Lavender $
+# $Id: Backends.py 12940 2021-06-03 15:19:56Z Lavender $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2021-05-20 13:20:59 +0800 (Thu, 20 May 2021) $
-# $Revision: 12906 $
+# $Date: 2021-06-03 23:19:56 +0800 (Thu, 03 Jun 2021) $
+# $Revision: 12940 $
 
 import re
 import os
@@ -31,6 +31,8 @@ DEFAULT_TRAC_AUTH_URL = getattr(settings,
     'DEFAULT_TRAC_AUTH_URL', 'https://code.nuwainfo.com/aec359bc3cfadb7504f26461a4c06625')
 DEFAULT_TRAC_AUTH_USERNAME = getattr(settings, 'DEFAULT_TRAC_AUTH_USERNAME', 'Deploy')
 DEFAULT_TRAC_AUTH_PASSWORD = getattr(settings, 'DEFAULT_TRAC_AUTH_PASSWORD', 'ei0W1aUeP1pcRvJoV4X8ZC2xm')
+SET_TRAC_LOGIN_AS_STAFF = getattr(settings, "SET_TRAC_LOGIN_AS_STAFF", False)
+SET_TRAC_LOGIN_AS_SUPERUSER = getattr(settings, "SET_TRAC_LOGIN_AS_SUPERUSER", False)
 
 USER_DATA_PATTERN = "#\s+?(\w+):\s+?(\{.+\}?)"
   
@@ -60,8 +62,8 @@ class TracBackend(ModelBackend):
             except User.DoesNotExist:
                 # Create a new user. There's no need to set a password
                 user = User(username=username, email=email)
-                user.is_staff = getattr(settings, "SET_TRAC_LOGIN_AS_STAFF", False)
-                user.is_superuser = getattr(settings, "SET_TRAC_LOGIN_AS_SUPERUSER", False)
+                user.is_staff = SET_TRAC_LOGIN_AS_STAFF
+                user.is_superuser = SET_TRAC_LOGIN_AS_SUPERUSER
                 user.save()
             return user
         return None
\ No newline at end of file
