@@ -20,7 +20,7 @@ from Iuno.test import RemoteTestCaseMixin
 
 class TestOscarDemo(TestCase, RemoteTestCaseMixin):
     
-    TEST_URL = "http://oscar.nuwainfo.com"
+    TEST_URL = "https://oscar.nuwainfo.com"
     TEST_SETTINGS = "tests.TestSettings"
         
 
